@@ -1,4 +1,4 @@
-# $Id: LibXSLT.pm,v 1.19 2001/06/07 09:48:19 matt Exp $
+# $Id: LibXSLT.pm,v 1.20 2001/06/09 13:31:54 matt Exp $
 
 package XML::LibXSLT;
 
@@ -9,7 +9,7 @@ use XML::LibXML;
 
 require Exporter;
 
-$VERSION = "1.05";
+$VERSION = "1.06";
 
 require DynaLoader;
 
@@ -24,6 +24,24 @@ sub new {
     return $self;
 }
 
+sub xpath_to_string {
+    my %params = @_;
+    foreach my $key (keys %params) {
+        if ($params{$key} =~ /\'/) {
+            $params{$key} = join('', 
+                "concat(", 
+                        join(', ', 
+                                map { "'$_', \"'\"" } 
+                                split /\'/, $params{$key}), 
+                                ")");
+        }
+        else {
+            $params{$key} = "'$params{$key}'";
+        }
+    }
+    return %params;
+}
+
 1;
 __END__
 
@@ -141,6 +159,25 @@ Returns the output encoding of the results. Defaults to "UTF-8".
 
 Returns the output media_type of the results. Defaults to "text/html".
 
+=head1 Parameters
+
+LibXSLT expects parameters in XPath format. That is, if you wish to pass
+a string to the XSLT engine, you actually have to pass it as a quoted
+string:
+
+  $stylesheet->transform($doc, param => "'string'");
+
+Note the quotes within quotes there!
+
+Obviously this isn't much fun, so you can make it easy on yourself:
+
+  $stylesheet->transform($doc, XML::LibXSLT::xpath_to_string(
+        param => "string"
+        ));
+
+The utility function does the right thing with respect to strings in XPath,
+including when you have quotes already embedded within your string.
+
 =head1 BENCHMARK
 
 Included in the distribution is a simple benchmark script, which has two
